package SSIS::Package::ConnectionManager::FLATFILE;

use 5.010;
use strict;
use warnings;

use parent qw/SSIS::Package::ConnectionManager/;

=head1 NAME

SSIS::Package::ConnectionManager::FLATFILE - SSIS FLATFILE package connection manager by Ded MedVed

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';


1 ;

__DATA__

1; # End of SSIS::Package::ConnectionManager::FLATFILE

